@@ -30,13 +30,13 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-07'; # DATE
+our $DATE = '2023-02-14'; # DATE
 our $DIST = 'TableDataBundle-Business-ID-KBLI'; # DIST
-our $VERSION = '20230207.0.0'; # VERSION
+our $VERSION = '20230214.0.0'; # VERSION
 
 with 'TableDataRole::Business::ID::KBLI::2020::Category';
 
-our %STATS = ("num_rows",21,"num_columns",3); # STATS
+our %STATS = ("num_columns",3,"num_rows",21); # STATS
 
 1;
 # ABSTRACT: List of KBLI categories
@@ -53,7 +53,7 @@ TableDataRole::Business::ID::KBLI::2020::Category - List of KBLI categories
 
 =head1 VERSION
 
-This document describes version 20230207.0.0 of TableDataRole::Business::ID::KBLI::2020::Category (from Perl distribution TableDataBundle-Business-ID-KBLI), released on 2023-02-07.
+This document describes version 20230214.0.0 of TableDataRole::Business::ID::KBLI::2020::Category (from Perl distribution TableDataBundle-Business-ID-KBLI), released on 2023-02-14.
 
 =head1 SYNOPSIS
 
